==> nextcloud-19.0.1-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/hr.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Učitavanje pretpregleda...",
    "Saved" : "Spremljeno",
    "Admin" : "Administrator",
    "a safe home for all your data" : "siguran dom za sve vaše podatke",
    "Name cannot be empty" : "Naziv ne može biti prazan",
    "The given name is too long" : "Naziv je predug",
    "The given web address is too long" : "Navedena adresa web-mjesta je preduga",
    "The given web address is not a valid URL" : "Navedena adresa web-mjesta nije važeći URL",
    "The given legal notice address is too long" : "Navedena adresa pravne obavijesti je preduga",
    "The given legal notice address is not a valid URL" : "Navedena adresa pravne obavijesti nije važeći URL",
    "The given privacy policy address is too long" : "Navedena adresa pravila o privatnosti je preduga",
    "The given privacy policy address is not a valid URL" : "Navedena adresa pravila o privatnosti nije važeći URL",
    "The given slogan is too long" : "Navedeni slogan je predug",
    "The given color is invalid" : "Navedena boja nije važeća",
    "The file was uploaded" : "Datoteka je otpremljena",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Otpremljena datoteka premašuje postavku upload_max_filesize u datoteci php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Otpremljena datoteka premašuje postavku MAX_FILE_SIZE koja je navedena u obrascu HTML-a",
    "The file was only partially uploaded" : "Datoteka je samo djelomično otpremljena",
    "No file was uploaded" : "Nije otpremljena nijedna datoteka",
    "Missing a temporary folder" : "Nedostaje privremena mapa",
    "Could not write file to disk" : "Nije moguće zapisati datoteku na disk",
    "A PHP extension stopped the file upload" : "Proširenje PHP-a zaustavilo je otpremanje datoteke",
    "No file uploaded" : "Nije otpremljena nijedna datoteka",
    "Unsupported image type" : "Nepodržana vrsta slike",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Već koristite prilagođenu temu. Te postavke mogu biti zamijenjene postavkama aplikacije za upravljanje temama.",
    "Theming" : "Upravljanje temama",
    "Legal notice" : "Pravna obavijest",
    "Privacy policy" : "Pravila o privatnosti",
    "Adjust the Nextcloud theme" : "Prilagodi temu Nextclouda",
    "Open documentation" : "Otvori dokumentaciju",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Upravljanje temama omogućuje jednostavno prilagođavanje izgleda vaše instance i podržanih klijenata. To će biti vidljivo svim korisnicima.",
    "Name" : "Naziv",
    "Reset to default" : "Vrati na zadanu postavku",
    "Web link" : "Web poveznica",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Boja",
    "Logo" : "Logotip",
    "Upload new logo" : "Otpremi novi logotip",
    "Login image" : "Slika za prijavu",
    "Upload new login background" : "Otpremi novu pozadinu za prijavu",
    "Remove background image" : "Ukloni pozadinsku sliku",
    "Advanced options" : "Napredne opcije",
    "Legal notice link" : "Poveznica na pravnu obavijest",
    "Privacy policy link" : "Poveznica na pravila o privatnosti",
    "Header logo" : "Logotip zaglavlja",
    "Upload new header logo" : "Otpremi novi logotip zaglavlja",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Otpremi novi favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Ugradite proširenje za PHP pod nazivom Imagemagick s podrškom za SVG slike kako biste automatski generirali favicone na temelju otpremljenog logotipa i boje."
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");

==> nextcloud-20.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/theming/l10n/hr.js <==
OC.L10N.register(
    "theming",
    {
    "Loading preview…" : "Učitavanje pretpregleda...",
    "Saved" : "Spremljeno",
    "Admin" : "Administrator",
    "a safe home for all your data" : "siguran dom za sve vaše podatke",
    "Name cannot be empty" : "Naziv ne može biti prazan",
    "The given name is too long" : "Naziv je predug",
    "The given web address is too long" : "Navedena adresa web-mjesta je preduga",
    "The given web address is not a valid URL" : "Navedena adresa web-mjesta nije važeći URL",
    "The given legal notice address is too long" : "Navedena adresa pravne obavijesti je preduga",
    "The given legal notice address is not a valid URL" : "Navedena adresa pravne obavijesti nije važeći URL",
    "The given privacy policy address is too long" : "Navedena adresa pravila o privatnosti je preduga",
    "The given privacy policy address is not a valid URL" : "Navedena adresa pravila o privatnosti nije važeći URL",
    "The given slogan is too long" : "Navedeni slogan je predug",
    "The given color is invalid" : "Navedena boja nije važeća",
    "The file was uploaded" : "Datoteka je otpremljena",
    "The uploaded file exceeds the upload_max_filesize directive in php.ini" : "Otpremljena datoteka premašuje postavku upload_max_filesize u datoteci php.ini",
    "The uploaded file exceeds the MAX_FILE_SIZE directive that was specified in the HTML form" : "Otpremljena datoteka premašuje postavku MAX_FILE_SIZE koja je navedena u obrascu HTML-a",
    "The file was only partially uploaded" : "Datoteka je samo djelomično otpremljena",
    "No file was uploaded" : "Nije otpremljena nijedna datoteka",
    "Missing a temporary folder" : "Nedostaje privremena mapa",
    "Could not write file to disk" : "Nije moguće zapisati datoteku na disk",
    "A PHP extension stopped the file upload" : "Proširenje PHP-a zaustavilo je otpremanje datoteke",
    "No file uploaded" : "Nije otpremljena nijedna datoteka",
    "You are already using a custom theme. Theming app settings might be overwritten by that." : "Već koristite prilagođenu temu. Te postavke mogu biti zamijenjene postavkama aplikacije za upravljanje temama.",
    "Theming" : "Upravljanje temama",
    "Legal notice" : "Pravna obavijest",
    "Privacy policy" : "Pravila o privatnosti",
    "Adjust the Nextcloud theme" : "Prilagodi temu Nextclouda",
    "Open documentation" : "Otvori dokumentaciju",
    "Theming makes it possible to easily customize the look and feel of your instance and supported clients. This will be visible for all users." : "Upravljanje temama omogućuje jednostavno prilagođavanje izgleda vaše instance i podržanih klijenata. To će biti vidljivo svim korisnicima.",
    "Name" : "Naziv",
    "Reset to default" : "Vrati na zadanu postavku",
    "Web link" : "Web poveznica",
    "https://…" : "https://…",
    "Slogan" : "Slogan",
    "Color" : "Boja",
    "Logo" : "Logotip",
    "Upload new logo" : "Otpremi novi logotip",
    "Login image" : "Slika za prijavu",
    "Upload new login background" : "Otpremi novu pozadinu za prijavu",
    "Remove background image" : "Ukloni pozadinsku sliku",
    "Advanced options" : "Napredne opcije",
    "Legal notice link" : "Poveznica na pravnu obavijest",
    "Privacy policy link" : "Poveznica na pravila o privatnosti",
    "Header logo" : "Logotip zaglavlja",
    "Upload new header logo" : "Otpremi novi logotip zaglavlja",
    "Favicon" : "Favicon",
    "Upload new favicon" : "Otpremi novi favicon",
    "Install the Imagemagick PHP extension with support for SVG images to automatically generate favicons based on the uploaded logo and color." : "Ugradite proširenje za PHP pod nazivom Imagemagick s podrškom za SVG slike kako biste automatski generirali favicone na temelju otpremljenog logotipa i boje.",
    "Unsupported image type" : "Nepodržana vrsta slike"
},
"nplurals=3; plural=n%10==1 && n%100!=11 ? 0 : n%10>=2 && n%10<=4 && (n%100<10 || n%100>=20) ? 1 : 2;");
